getIdentities method
Returns the identities currently known to the Adobe SDK.
Implementation
Future<dynamic> getIdentities() async {
return await _identity.getIdentities();
}
Returns the identities currently known to the Adobe SDK.
Future<dynamic> getIdentities() async {
return await _identity.getIdentities();
}