AdobeAnalyticsIdentity class

Constructors

AdobeAnalyticsIdentity()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getExperienceCloudId() Future
getIdentities() Future
getUrlVariables() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIdentity(Map<String, dynamic> parameters) Future
resetIdentities() Future
setAdvertisingIdentifier(String advertisingIdentifier) Future
toString() String
A string representation of this object.
inherited
updateIdentities(Map<String, dynamic> parameters) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited