AdobeAnalyticsUserProfile class

Constructors

AdobeAnalyticsUserProfile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUserAttributes(List<String> attributes) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeUserAttributes(List<String> attributeName) Future<void>
toString() String
A string representation of this object.
inherited
updateUserAttributes(Map<String, Object> attributeMap) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited