AdobeAnalyticsImpl class
Coordinates Adobe Experience Platform analytics APIs for Ensemble.
Constructors
- AdobeAnalyticsImpl({required String appId})
-
Creates the shared Adobe Analytics module instance for
appId.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConsents(
) → Future -
Returns the current Adobe consent preferences.
override
-
getExperienceCloudId(
) → Future -
Returns the current Experience Cloud ID.
override
-
getIdentities(
) → Future -
Returns the identities currently known to the Adobe SDK.
override
-
getUrlVariables(
) → Future -
Returns Adobe identity URL variables for hybrid web views.
override
-
getUserAttributes(
Map< String, dynamic> parameters) → Future<String> -
Reads user profile attributes named in
parameters.override -
initialize(
String appId) → Future -
Initializes Adobe Analytics with the supplied mobile property
appId.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeIdentity(
Map< String, dynamic> parameters) → Future -
Removes one identity described by
parameters.override -
removeUserAttributes(
Map< String, dynamic> parameters) → Future<void> -
Removes user profile attributes named in
parameters.override -
resetIdentities(
) → Future -
Clears SDK identities and returns the refreshed identity state.
override
-
sendEvent(
String name, Map< String, dynamic> ? parameters) → Future -
Sends an Experience Edge event with optional XDM and data
parameters.override -
setAdvertisingIdentifier(
String advertisingIdentifier) → Future -
Sets or clears the advertising identifier used by the SDK.
override
-
setDefaultConsent(
bool allowed) → Future< void> -
Sets the default collect consent preference.
override
-
setupAssurance(
Map< String, dynamic> parameters) → Future<void> -
Starts Adobe Assurance using the provided connection
parameters.override -
toString(
) → String -
A string representation of this object.
inherited
-
trackAction(
String name, Map< String, String> ? parameters) → Future -
Tracks a user action with optional string
parameters.override -
trackState(
String name, Map< String, String> ? parameters) → Future -
Tracks an app state or screen with optional string
parameters.override -
updateConsent(
bool allowed) → Future< void> -
Updates the collect consent preference.
override
-
updateIdentities(
Map< String, dynamic> parameters) → Future -
Merges the supplied identity
parametersinto the SDK identity map.override -
updateUserAttributes(
Map< String, dynamic> parameters) → Future<void> -
Updates user profile attributes from
parameters.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited