AdobeAnalyticsCore class
Constructors
- AdobeAnalyticsCore({required String appId})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize(
String appId) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackAction(
String name, Map< String, String> ? parameters) → Future -
trackState(
String name, Map< String, String> ? parameters) → Future
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited